#!/bin/ksh -p

# $Id: txn.sh,v 1.1.4.2.2.4.2.3 2016/02/29 21:58:12 rosacc Exp $

# terminate on non-zero command exit status
set -e

PROGRAM_NAME="$0"

COMMANDS="help match send"

function main
{
    typeset BIN=$(cd $(dirname "$PROGRAM_NAME") ; pwd -P)

    . "$BIN/functions.sh"
    
    clear_env
    
    typeset ETC="$(absolute_path $BIN/../etc)"

    SRV="$ETC/ose.properties"
    
    if [ -r "$SRV" ] ; then
        read_properties_file "$SRV"
    fi
    
    read_properties_file "$ETC/txn.properties"

    if [ -r "$SRV" ] ; then
        init_server_env
    else 
        init_standalone_env
    fi

    OPTS="$OPTS -Dlog4j.configurationFile=${LOG4J_CONFIG:?}"
    # comment this out to get log4j logs in local time; by default the ose.sh script has the same property set
    OPTS="$OPTS -Duser.timezone=UTC"
 #   OPTS="$OPTS -verbose:class"

    if [ -n "$DEBUG_PORT" ] ; then
        OPTS="$OPTS $(debug_opts)"
    fi

    : ${TXN_XML:="file://${CONFIG_DIR:?}/txn.xml"}

    for cmd in "$@"
    do
        case "$cmd" in
        
        help  )   usage ;;
        match )   loadGenerator "$@"
                  break;;
        send  )   loadGenerator "$@"
                  break;;
        *     )   echo "unknown command: '$cmd'" && usage && exit 1 ;;
        
        esac
    done
    
    if [ $# -eq 0 ] ; then
        usage
        exit 1
    fi
}

function init_standalone_env
{
    init_common_env
    
    if [ -z "$LOG4J_CONFIG" ] ; then
        # LOG4J_CONFIG is a resource path, not a file system path.
        # It is found via the (SAS) ClassLoader. 
        LOG4J_CONFIG="log4j.xml"
        file_readable "${CONFIG_DIR:?}/${LOG4J_CONFIG}" ""
    fi

    if [ -n "$MQ_HOME" ] ; then
        init_mq_env

        OPTS="$OPTS -Djava.library.path=${LIBRARY_PATH:?}"
    fi
    
    if [ -n "${LIB_DIR}" ] ; then
        CLASSPATH="$CLASSPATH:${LIB_DIR}/*"
    fi

    for D in $(echo ${CLASS_DIRS:?} | tr ':' ' ')
    do
        CLASSPATH="$CLASSPATH:$D/*"
    done
 
    OPTS="$OPTS -Xmx${JAVA_HEAP:?}"
    OPTS="$OPTS -Xms${JAVA_HEAP:?}"
    OPTS="$OPTS -Xmn${JAVA_YOUNG_HEAP:?}"
    OPTS="$OPTS -classpath ${CLASSPATH:?}"
}

function loadGenerator
{
    for bean in "$1"
    do
        case "$bean" in

        match )   ;;
        send  )   ;;
        *     )   echo "unknown bean: '$bean'" && usage && exit 1 ;;

        esac
    done

    typeset CMD="${JAVA:?}"
    
    shift
    for opt in "$@"
    do 
       if [[ ! ${opt} = {1}(+(\w)=+([[:graph:]])) ]]; then 
         echo "invalid property:'"${opt}"' must be of the form key=value" && exit 1; 
       fi
       OPTS="$OPTS -D${opt}"
    done

    CMD="$CMD $OPTS"
    CMD="$CMD com.sas.finance.fraud.engine.client.tools.LoadGenerator"
    CMD="$CMD -config ${TXN_XML:?} ${BEAN_NAME:="$bean"}"
    
    echo
    date
    echo
    "${JAVA:?}" -version 2>&1
    echo
    echo "$CMD"
    echo

    set +e
    $CMD

    if [ $? -ne 0 -a -z "$VJR_HOME" ] ; then
        standalone_jar_list
    fi
}

function standalone_jar_list
{
    echo <<!
commons_logging
guava
log4j
netty
#sas.finance.fraud.engine
#sas.finance.fraud.transaction
org.springframework.beans
org.springframework.context
org.springframework.core
org.springframework.expression
!
}

function usage
{
    echo "Usage: ${PROGRAM_NAME:?} [ ${COMMANDS:?} ]"
}

main "$@"


